# Relic Tool
[![PyPI](https://img.shields.io/pypi/v/relic-tool)](https://pypi.org/project/Relic-Tool/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/relic-tool)](https://www.python.org/downloads/)
[![PyPI - License](https://img.shields.io/pypi/l/relic-tool)](https://github.com/MAK-Relic-Tool/Relic-Tool/blob/main/LICENSE.txt)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Build Check](https://github.com/MAK-Relic-Tool/Relic-Tool/actions/workflows/build-check.yml/badge.svg)](https://github.com/MAK-Relic-Tool/Relic-Tool/actions/workflows/build-check.yml)
#### Disclaimer
Not affiliated with Sega, Relic Entertainment, or THQ.

#### Description
A library which allows the reading/writing of Relic's proprietary file formats; SGA files (.sga), Relic Chunky files, and UCS language files (.ucs).

## Installation (Pip)
### Installing from PyPI (Recommended)
```
pip install relic-tool
```
### Installing from GitHub
For more information, see [pip VCS support](https://pip.pypa.io/en/stable/topics/vcs-support/#git)
```
pip install git+https://github.com/MAK-Relic-Tool/Relic-Tool
```
